==> huaweicloudsdkvpc-3.1.123-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_firewall_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteFirewallTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'firewall_id': 'str',
        'tag_key': 'str'
    }

    attribute_map = {
        'firewall_id': 'firewall_id',
        'tag_key': 'tag_key'
    }

    def __init__(self, firewall_id=None, tag_key=None):
        """DeleteFirewallTagRequest

        The model defined in huaweicloud sdk

        :param firewall_id: 功能说明：ACL唯一标识 取值范围：合法UUID 约束：ID对应的ACL必须存在
        :type firewall_id: str
        :param tag_key: 功能说明：标签键
        :type tag_key: str
        """
        
        

        self._firewall_id = None
        self._tag_key = None
        self.discriminator = None

        self.firewall_id = firewall_id
        self.tag_key = tag_key

    @property
    def firewall_id(self):
        """Gets the firewall_id of this DeleteFirewallTagRequest.

        功能说明：ACL唯一标识 取值范围：合法UUID 约束：ID对应的ACL必须存在

        :return: The firewall_id of this DeleteFirewallTagRequest.
        :rtype: str
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this DeleteFirewallTagRequest.

        功能说明：ACL唯一标识 取值范围：合法UUID 约束：ID对应的ACL必须存在

        :param firewall_id: The firewall_id of this DeleteFirewallTagRequest.
        :type firewall_id: str
        """
        self._firewall_id = firewall_id

    @property
    def tag_key(self):
        """Gets the tag_key of this DeleteFirewallTagRequest.

        功能说明：标签键

        :return: The tag_key of this DeleteFirewallTagRequest.
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this DeleteFirewallTagRequest.

        功能说明：标签键

        :param tag_key: The tag_key of this DeleteFirewallTagRequest.
        :type tag_key: str
        """
        self._tag_key = tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteFirewallTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_firewall_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteFirewallTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'firewall_id': 'str',
        'tag_key': 'str'
    }

    attribute_map = {
        'firewall_id': 'firewall_id',
        'tag_key': 'tag_key'
    }

    def __init__(self, firewall_id=None, tag_key=None):
        r"""DeleteFirewallTagRequest

        The model defined in huaweicloud sdk

        :param firewall_id: 功能说明：ACL唯一标识 取值范围：合法UUID 约束：ID对应的ACL必须存在
        :type firewall_id: str
        :param tag_key: 功能说明：标签键
        :type tag_key: str
        """
        
        

        self._firewall_id = None
        self._tag_key = None
        self.discriminator = None

        self.firewall_id = firewall_id
        self.tag_key = tag_key

    @property
    def firewall_id(self):
        r"""Gets the firewall_id of this DeleteFirewallTagRequest.

        功能说明：ACL唯一标识 取值范围：合法UUID 约束：ID对应的ACL必须存在

        :return: The firewall_id of this DeleteFirewallTagRequest.
        :rtype: str
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        r"""Sets the firewall_id of this DeleteFirewallTagRequest.

        功能说明：ACL唯一标识 取值范围：合法UUID 约束：ID对应的ACL必须存在

        :param firewall_id: The firewall_id of this DeleteFirewallTagRequest.
        :type firewall_id: str
        """
        self._firewall_id = firewall_id

    @property
    def tag_key(self):
        r"""Gets the tag_key of this DeleteFirewallTagRequest.

        功能说明：标签键

        :return: The tag_key of this DeleteFirewallTagRequest.
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        r"""Sets the tag_key of this DeleteFirewallTagRequest.

        功能说明：标签键

        :param tag_key: The tag_key of this DeleteFirewallTagRequest.
        :type tag_key: str
        """
        self._tag_key = tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteFirewallTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
